A Python parser of files generated by Synergy plate readers

*	You can install it with something along the lines of:

		pip install synergy-file-reader

*	[Read the friendly documentation](https://synergy-file-reader.readthedocs.io).

*	If you have any issues or feature requests, please [report them](https://github.com/BPSB/Synergy-File-Reader/issues).
